@@ -32,8 +32,8 @@ Provides location to maintain version information.
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
-COPYRIGHT   = "2004-2011,2013-2015"
-VERSION     = "3.1.4"
-DATE        = "11 Aug 2015"
+COPYRIGHT   = "2004-2011,2013-2016"
+VERSION     = "3.1.5"
+DATE        = "02 Jan 2016"
 URL         = "https://bitbucket.org/cedarsolutions/cedar-backup3"
 
